@@ -111,6 +111,24 @@ OAuth::Lite::Consumer - consumer agent
 
 This module helps you to build OAuth Consumer application.
 
+=head1 PAY ATTENTION
+
+If you use OAuth 1.31 or older version, its has invalid way to normalize params.
+(when there are two or more same key and they contain ASCII and non ASCII value)
+
+But the many services have already supported deprecated version, 
+and the correct way breaks backward compatibility.
+So, from 1.32, supported both correct and deprecated method. 
+
+use $OAuth::Lite::USE_DEPRECATED_NORMALIZER to switch behaviour.
+Currently 1 is set by default to keep backward compatibility.
+
+    use OAuth::Lite::Consumer;
+    use OAuth::Lite;
+
+    $OAuth::Lite::USE_DEPRECATED_NORMALIZER = 0;
+    ...
+
 =head1 METHODS
 
 =head2 new(%args)
